instrumenttools.EnglishHorn
===========================

.. inheritance-diagram:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn
   :private-bases:

.. autoclass:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.default_instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.default_short_instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.effective_context

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.format

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.interval_of_transposition

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.is_primary_instrument

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.is_secondary_instrument

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.is_transposing

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.start_component

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.target_context

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.traditional_pitch_range

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.all_clefs

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.instrument_name_markup

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.pitch_range

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.primary_clefs

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.short_instrument_name

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.short_instrument_name_markup

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. autoattribute:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.sounding_pitch_of_fingered_middle_c

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Methods
-------

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.attach

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.detach

    Inherited from :py:class:`contexttools.ContextMark <abjad.tools.contexttools.ContextMark.ContextMark.ContextMark>`

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.get_default_performer_name

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.get_performer_names

    Inherited from :py:class:`instrumenttools._Instrument <abjad.tools.instrumenttools._Instrument._Instrument._Instrument>`

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__call__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__delattr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__eq__

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__hash__

    Inherited from :py:class:`contexttools.InstrumentMark <abjad.tools.contexttools.InstrumentMark.InstrumentMark.InstrumentMark>`

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__ne__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__repr__

    Inherited from :py:class:`marktools.Mark <abjad.tools.marktools.Mark.Mark.Mark>`

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__setattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.instrumenttools.EnglishHorn.EnglishHorn.EnglishHorn.__str__

    Inherited from `__builtin__.object`
